==> HinemosWebClient_src-1.0.0.tar.gz: HinemosWebClient_src-1.0.0/src/com/necsoft/hinemos/webclient/bean/TreeInfo.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.bean;

public class TreeInfo {
	/**
	 * 
	 */
	String title;
	String tooltip;
	Boolean isFolder;
	String addClass;

	/**
	 * @return the title
	 */
	public String getTitle() {
		return title;
	}

	/**
	 * @param title
	 *            the title to set
	 */
	public void setTitle(String title) {
		this.title = title;
	}

	/**
	 * @return the tooltip
	 */
	public String getTooltip() {
		return tooltip;
	}

	/**
	 * @param tooltip
	 *            the tooltip to set
	 */
	public void setTooltip(String tooltip) {
		this.tooltip = tooltip;
	}

	/**
	 * @return the isFolder
	 */
	public Boolean getIsFolder() {
		return isFolder;
	}

	/**
	 * @param isFolder
	 *            the isFolder to set
	 */
	public void setIsFolder(Boolean isFolder) {
		this.isFolder = isFolder;
	}

	/**
	 * @return the addClass
	 */
	public String getAddClass() {
		return addClass;
	}

	/**
	 * @param addClass
	 *            the addClass to set
	 */
	public void setAddClass(String addClass) {
		this.addClass = addClass;
	}

}

==> HinemosWebClient_src-2.0.2.tar.gz: HinemosWebClient_src-2.0.2/src/com/necsoft/hinemos/webclient/bean/TreeInfo.java <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.necsoft.hinemos.webclient.bean;

public class TreeInfo {
	/**
	 * 
	 */
	private String title;
	private String tooltip;
	private boolean isFolder;
	private String addClass;

	/**
	 * @return the title
	 */
	public String getTitle() {
		return title;
	}

	/**
	 * @param title
	 *            the title to set
	 */
	public void setTitle(String title) {
		this.title = title;
	}

	/**
	 * @return the tooltip
	 */
	public String getTooltip() {
		return tooltip;
	}

	/**
	 * @param tooltip
	 *            the tooltip to set
	 */
	public void setTooltip(String tooltip) {
		this.tooltip = tooltip;
	}

	/**
	 * @return the isFolder
	 */
	public boolean getIsFolder() {
		return isFolder;
	}

	/**
	 * @param isFolder
	 *            the isFolder to set
	 */
	public void setIsFolder(boolean isFolder) {
		this.isFolder = isFolder;
	}

	/**
	 * @return the addClass
	 */
	public String getAddClass() {
		return addClass;
	}

	/**
	 * @param addClass
	 *            the addClass to set
	 */
	public void setAddClass(String addClass) {
		this.addClass = addClass;
	}

}
